<template>
  <gree-popup v-model="isShow" position="top" @hide="hidePopup">
    <div class="drop-down-popup">
      <div class="drop-down-popup-close">
        <gree-icon name="cross" size="20px" @click="onClose" />
      </div>
      <gree-list>
        <gree-list-item link :title="$language('moreInfo.devInfo')" @click.native="moreInfo"></gree-list-item>
        <gree-list-item link :title="$language('moreInfo.voiceSkill')" @click.native="voiceSkill"></gree-list-item>
      </gree-list>
    </div>
  </gree-popup>
</template>

<script>
import { editDevice, startVoiceMainActivity } from '@PluginInterface';
import { Popup, List, Item, Icon } from 'gree-ui';
import { mapMutations, mapActions, mapState } from 'vuex';
import BtnGroup from '@/components/BtnGroup/index';
import CardGroup from '@/components/CardGroup/index';

export default {
  name: 'drop-down-popup',
  components: {
    [Popup.name]: Popup,
    [List.name]: List,
    [Item.name]: Item,
    [Icon.name]: Icon,
    [BtnGroup.name]: BtnGroup,
    [CardGroup.name]: CardGroup
  },
  data() {
    return {
      isShow: false
    };
  },
  computed: {
    ...mapState('control', {
      dropDownList: state => state.popup.dropDownList,
      mac: state => state.mac
    })
  },
  watch: {
    isShow(newVal) {
      !newVal && this.SetPopup({ dropDownList: false });
    },
    dropDownList: {
      handler(newVal) {
        this.isShow = newVal;
      },
      immediate: true
    }
  },
  methods: {
    ...mapMutations('control', {
      SetPopup: 'SET_POPUP'
    }),
    ...mapActions({}),
    hidePopup() {
      this.SetPopup({ dropDownList: false });
    },
    moreInfo() {
      this.hidePopup();
      editDevice(this.mac);
    },
    voiceSkill() {
      this.hidePopup();
      startVoiceMainActivity(this.mac);
    },
    hidePopUpTop(type) {
      this.$set(this.isPopupShow3, type, false);
    },
    onClose() {
      this.isShow = false;
    }
  }
};
</script>

<style lang="scss">
.drop-down-popup {
  margin-top: env(safe-area-inset-top);
  width: 100%;
  background-color: #fff;
  &-close {
    position: relative;
    height: 110px;
    overflow: visible;
    box-sizing: content-box;
    .gree-icon.gree-icon-cross {
      position: absolute;
      right: 60px;
      top: 40px;
    }
  }
}
</style>
